@@ -2,18 +2,19 @@
 Functions related to core conda functionality that relates to manually
 installed Python packages, e.g. using "python setup.py install", or "pip".
 """
-from __future__ import absolute_import, division, print_function
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from io import open
 import os
+from os.path import isdir, isfile, join
 import re
 import sys
-from os.path import isdir, isfile, join
 
-from .compat import itervalues
-from .install import linked_data
+from .common.compat import itervalues, on_win
+from .core.prefix_data import linked_data
 from .misc import rel_path
-from .utils import on_win
+from .models.dist import Dist
+
 
 def get_site_packages_dir(installed_pkgs):
     for info in itervalues(installed_pkgs):
@@ -28,7 +29,11 @@ def get_site_packages_dir(installed_pkgs):
 
 
 def get_egg_info_files(sp_dir):
-    for fn in os.listdir(sp_dir):
+    for fn in (isdir(sp_dir) and os.listdir(sp_dir) or ()):
+        if fn.endswith('.egg-link'):
+            with open(join(sp_dir, fn), 'r') as reader:
+                for egg in get_egg_info_files(reader.readline().strip()):
+                    yield egg
         if not fn.endswith(('.egg', '.egg-info', '.dist-info')):
             continue
         path = join(sp_dir, fn)
@@ -70,7 +75,7 @@ def get_egg_info(prefix, all_pkgs=False):
     """
     installed_pkgs = linked_data(prefix)
     sp_dir = get_site_packages_dir(installed_pkgs)
-    if sp_dir is None:
+    if sp_dir is None or not isdir(join(prefix, sp_dir)):
         return set()
 
     conda_files = set()
@@ -86,7 +91,7 @@ def get_egg_info(prefix, all_pkgs=False):
             except UnicodeDecodeError:
                 dist = None
             if dist:
-                res.add(dist)
+                res.add(Dist(dist))
     return res
 
 
