@@ -462,6 +462,13 @@ class PackagesNotFoundError(CondaError):
             Current channels:
 
             %(channels_formatted)s
+
+            To search for alternate channels that may provide the conda package you're
+            looking for, navigate to
+
+                https://anaconda.org
+
+            and use the search bar at the top of the page.
             """)
             packages_formatted = format_list(packages)
             channels_formatted = format_list(channel_urls)
@@ -915,6 +922,10 @@ class ExceptionHandler(object):
             'traceback': _format_exc(exc_val, exc_tb),
             'conda_info': info_dict,
         }
+
+        if isinstance(exc_val, CondaError):
+            error_report['conda_error_components'] = exc_val.dump_map()
+
         return error_report
 
     def print_unexpected_error_report(self, error_report):
